@@ -57,13 +57,9 @@ sub from_arguments_to_choices {
                         my ($pid, $exit_code, $ident, $exit_signal, $core_dump, $data_structure_reference) = @_;
                         if ( defined $data_structure_reference ) {
                             my ( $id, $single_data ) = @{${$data_structure_reference}};
-                            if ( defined $id ) {
-                                printf "\r%s %d/%d", $message, $c++, $min;
-                                for my $key ( keys %$single_data ) {
-                                    $data->{$ex}{$up}{$id}{$key} = $single_data->{$key};
-                                }
-                            }
-                            else {
+                            printf "\r%s %d/%d", $message, $c++, $min;
+                            for my $key ( keys %$single_data ) {
+                                $data->{$ex}{$up}{$id}{$key} = $single_data->{$key};
                             }
                         }
                         else {  # problems occurring during storage or retrieval will throw a warning
@@ -73,35 +69,31 @@ sub from_arguments_to_choices {
                 );
 
                 DATA_LOOP: for my $i ( 0 .. $min - 1 ) {
-                    # next ###
-                    my $pid = $pm->start and next DATA_LOOP;
                     my $id = $ids->[$i];
-                    my $data_structure_reference;
                     if ( exists $data->{$ex}{$up}{$id}{fmt_to_info} ) {
-                        $data_structure_reference = [];
+                        next DATA_LOOP;
+                    }
+                    my $pid = $pm->start and next DATA_LOOP;
+                    my $url = $data->{$ex}{$up}{$id}{url};
+                    my $h_ref;
+                    my $single_data;
+                    if ( eval { $h_ref = get_download_info( $set, $opt, $url, 0 ); 1 } ) {
+                        $single_data = extract_data_single( $set, $opt, $h_ref );
                     }
                     else {
-                        my $url = $data->{$ex}{$up}{$id}{url};
-                        my $h_ref;
-                        my $single_data;
-                        if ( eval { $h_ref = get_download_info( $set, $opt, $url, 0 ); 1 } ) {
-                            $single_data = extract_data_single( $set, $opt, $h_ref );
-                        }
-                        else {
-                            $single_data = { description => $set->{failed_fetching_data} };
-                        }
-                        $data_structure_reference = [ $id, $single_data ];
+                        $single_data = { description => $set->{failed_fetching_data} };
                     }
+                    my $data_structure_reference = [ $id, $single_data ];
                     $pm->finish( 0, \$data_structure_reference );
                 }
                 $pm->wait_all_children;
             }
             my $prompt = $data->{$ex}{$up}{$ids->[0]}{uploader} || $webpage_url;
-            my $upurl_chosen = choose_videos( $set, $opt, $data, $ex, $up, $ids, $prompt );
-            if ( ! defined $upurl_chosen ) {
+            my $chosen_ids = choose_videos( $set, $opt, $data, $ex, $up, $ids, $prompt );
+            if ( ! defined $chosen_ids ) {
                 next URL;
             }
-            push @{$chosen->{$ex}{$up}}, @$upurl_chosen;
+            push @{$chosen->{$ex}{$up}}, @$chosen_ids;
         }
     }
     if ( @failed_download_list_info ) {
